#ifndef LEGACYAPP_H
#define LEGACYAPP_H

#include <QObject>
#include <QSettings>
#include <QApplication>
#include <QVector>
#include <QVariant>

#include <LotroDat/LotroDat.h>

class LotroDatManager : public QObject
{
    Q_OBJECT

public:
    enum Category : int {
        E_TEXTS_COMMON = 100,
        E_TEXTS_ITEMS = 101,
        E_TEXTS_EMOTES = 102,
        E_TEXTS_VIDEOS = 103,
        E_MAPS_COMMON = 200,
        E_TEXTURES_COMMON = 201,
        E_AUDIOS_COMMON = 300
    };

public:
    explicit LotroDatManager(QObject *parent = nullptr);

    bool Initialised();

    bool NotPatched();

    unsigned getPercent();

public slots:
    void initializeManager();

    void deinitializeManager();

    void startGame(LOTRO_DAT::DatLocaleManager::LOCALE locale);

    void installPatch(QString patch_name, QString database_path);

    void enableCategory(QString patch_name, Category category);

    void disableCategory(QString patch_name, Category category);

    void createBackup();

    void restoreFromBackup();

    void removeBackup();

private:
    bool startLotroLauncherWithParameters(LOTRO_DAT::DatLocaleManager::LOCALE locale);

signals:
    void operationStarted(QString operation_name, QVector<QVariant> args = {});
    void errorOccured(QString operation_name, QVector<QVariant> args = {}, QString message = "No error message provided");
    void operationFinished(QString operation_name, QVector<QVariant> args = {}, bool successful = true);

private:
    LOTRO_DAT::DatFile client_local_file;
    LOTRO_DAT::DatFile client_general_file;
};

#endif // LEGACYAPP_H
